<?php

namespace Bixo\Niche\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Niche\Models\Niche;

class NichePolicy
{

    /**
     * Determine if the given user can view the niche.
     *
     * @param UserPolicy $user
     * @param Niche $niche
     *
     * @return bool
     */
    public function view(UserPolicy $user, Niche $niche)
    {
        if ($user->canDo('niche.niche.view') && $user->isAdmin()) {
            return true;
        }

        return $niche->user_id == user_id() && $niche->user_type == user_type();
    }

    /**
     * Determine if the given user can create a niche.
     *
     * @param UserPolicy $user
     * @param Niche $niche
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('niche.niche.create');
    }

    /**
     * Determine if the given user can update the given niche.
     *
     * @param UserPolicy $user
     * @param Niche $niche
     *
     * @return bool
     */
    public function update(UserPolicy $user, Niche $niche)
    {
        if ($user->canDo('niche.niche.edit') && $user->isAdmin()) {
            return true;
        }

        return $niche->user_id == user_id() && $niche->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given niche.
     *
     * @param UserPolicy $user
     * @param Niche $niche
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Niche $niche)
    {
        return $niche->user_id == user_id() && $niche->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given niche.
     *
     * @param UserPolicy $user
     * @param Niche $niche
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Niche $niche)
    {
        if ($user->canDo('niche.niche.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given niche.
     *
     * @param UserPolicy $user
     * @param Niche $niche
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Niche $niche)
    {
        if ($user->canDo('niche.niche.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
