<?php

namespace Bixo\Niche\Workflow;

use Bixo\Niche\Models\Niche;
use Validator;

class NicheValidator
{

    /**
     * Determine if the given niche is valid for complete status.
     *
     * @param Niche $niche
     *
     * @return bool / Validator
     */
    public function complete(Niche $niche)
    {
        return Validator::make($niche->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given niche is valid for verify status.
     *
     * @param Niche $niche
     *
     * @return bool / Validator
     */
    public function verify(Niche $niche)
    {
        return Validator::make($niche->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given niche is valid for approve status.
     *
     * @param Niche $niche
     *
     * @return bool / Validator
     */
    public function approve(Niche $niche)
    {
        return Validator::make($niche->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given niche is valid for publish status.
     *
     * @param Niche $niche
     *
     * @return bool / Validator
     */
    public function publish(Niche $niche)
    {
        return Validator::make($niche->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given niche is valid for archive status.
     *
     * @param Niche $niche
     *
     * @return bool / Validator
     */
    public function archive(Niche $niche)
    {
        return Validator::make($niche->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given niche is valid for unpublish status.
     *
     * @param Niche $niche
     *
     * @return bool / Validator
     */
    public function unpublish(Niche $niche)
    {
        return Validator::make($niche->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
